# Larch Documentation

[![conda-forge](https://img.shields.io/conda/vn/conda-forge/larch.svg)](https://anaconda.org/conda-forge/larch)
[![conda-forge](https://img.shields.io/conda/dn/conda-forge/larch)](https://anaconda.org/conda-forge/larch)
[![conda-forge](https://img.shields.io/azure-devops/build/wire-paladin/larch/jpn--.larch/master)](https://dev.azure.com/wire-paladin/larch/_build?definitionId=1&_a=summary&repositoryFilter=1&branchFilter=5%2C5%2C5%2C5%2C5%2C5)

🏆︁ Winner of the [AGIFORS 56th Annual Symposium Best Innovation award](http://agifors.org/Symposium).

This is the in-development documentation for Larch v6.

:::{note}
This project is very much under development.  There are plenty of undocumented functions
and features; use them at your own risk.  Undocumented features may be non-functional,
not rigorously tested, deprecated or removed without notice in a future version.  If a
function or method is documented here, it is intended to be stable in future updates.
:::
